@@ -92,8 +92,5 @@ schmitt.specific.names <- c("Kadipose2pu",
 # Do we ignore the Fups where the value was below the limit of detection?
 model.list[["schmitt"]]$exclude.fup.zero <- TRUE  
 
-# Filter out volatile compounds with Henry's Law Constant Threshold
-model.list[["schmitt"]]$log.henry.threshold <- c(-4.5)
-
 # Filter out compounds belonging to select chemical classes
 model.list[["schmitt"]]$chem.class.filt <- c("PFAS")
