@@ -13,7 +13,7 @@
 #' rest-of-body, with the plasma equivalent to the liver plasma.
 #' 
 #' Model Figure 
-#' \if{html}{\figure{3comp.png}{options: width="60\%" alt="Figure: Three
+#' \if{html}{\figure{3comp.jpg}{options: width="60\%" alt="Figure: Three
 #' Compartment Model Schematic"}} 
 #' \if{latex}{\figure{3comp.pdf}{options: width=12cm alt="Figure: Three Compartment
 #' Model Schematic"}}
@@ -47,8 +47,11 @@
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or
 #' default "Human").
 #' @param iv.dose Simulates a single i.v. dose if true.
-#' @param output.units Desired units (either "mg/L", "mg", "umol", or default
-#' "uM").
+#' @param input.units Input units of interest assigned to dosing,
+#' defaults to mg/kg BW
+#' @param output.units A named vector of output units expected for the model
+#' results. Default, NULL, returns model results in units specified in the
+#' 'modelinfo' file. See table below for details.
 #' @param method Method used by integrator (deSolve).
 #' @param rtol Argument passed to integrator (deSolve).
 #' @param atol Argument passed to integrator (deSolve).
@@ -103,7 +106,7 @@ solve_3comp <- function(chem.name = NULL,
                     parameters=NULL,
                     days=10,
                     tsteps = 4, # tsteps is number of steps per hour
-                    daily.dose = NULL, # Assume dose is in mg/kg BW/day
+                    daily.dose = NULL, 
                     dose = NULL,
                     doses.per.day=NULL,
                     initial.values=NULL,
@@ -111,7 +114,9 @@ solve_3comp <- function(chem.name = NULL,
                     suppress.messages=FALSE,
                     species="Human",
                     iv.dose=FALSE,
-                    output.units='uM',
+                    input.units='mg/kg',
+                    # output.units='uM',
+                    output.units=NULL,
                     method="lsoda",rtol=1e-8,atol=1e-12,
                     default.to.human=FALSE,
                     recalc.blood2plasma=FALSE,
@@ -119,7 +124,7 @@ solve_3comp <- function(chem.name = NULL,
                     dosing.matrix=NULL,
                     adjusted.Funbound.plasma=TRUE,
                     regression=TRUE,
-                    restrictive.clearance = T,
+                    restrictive.clearance = TRUE,
                     minimum.Funbound.plasma=0.0001,
                     monitor.vars=NULL,
                     ...)
@@ -145,6 +150,7 @@ solve_3comp <- function(chem.name = NULL,
     monitor.vars=monitor.vars,
     suppress.messages=suppress.messages,
     species=species,
+    input.units=input.units,
     output.units=output.units,
     method=method,rtol=rtol,atol=atol,
     default.to.human=default.to.human,
